from setuptools import setup

setup(name='neurascope',
      version='0.0.1',
      description='The neural network doctor will see you now',
      url='http://github.com/rkaplan/neurascope',
      author='Russell Kaplan',
      author_email='rjkaplan@cs.stanford.edu',
      license='MIT',
      packages=['neurascope'],
      zip_safe=False)

